---
permalink: /docs/index.html
---

# Docs
https://paulfogel.github.io/NMTF/

# NMTF

Non-Negative Matrix and Tensor Factorizations

## Medium article
**Using Non-negative matrix factorization to classify companies** : 
https://medium.com/@chtill.g/using-nmf-to-classify-companies-a77e176f276f